act.plotting.XSectionDisplay
============================

.. currentmodule:: act.plotting

.. autoclass:: XSectionDisplay

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~XSectionDisplay.__init__
      ~XSectionDisplay.add_colorbar
      ~XSectionDisplay.add_subplots
      ~XSectionDisplay.assign_to_figure_axis
      ~XSectionDisplay.plot_xsection
      ~XSectionDisplay.plot_xsection_map
      ~XSectionDisplay.put_display_in_subplot
      ~XSectionDisplay.set_subplot_to_map
      ~XSectionDisplay.set_xrng
      ~XSectionDisplay.set_yrng
   
   

   
   
   